@@ -1,8 +1,8 @@
 Prism.languages['nand2tetris-hdl'] = {
 	'comment': /\/\/.*|\/\*[\s\S]*?(?:\*\/|$)/,
-	'keyword': /\b(?:CHIP|IN|OUT|PARTS|BUILTIN|CLOCKED)\b/,
-	'boolean': /\b(?:true|false)\b/,
-	'function': /[A-Za-z][A-Za-z0-9]*(?=\()/,
+	'keyword': /\b(?:BUILTIN|CHIP|CLOCKED|IN|OUT|PARTS)\b/,
+	'boolean': /\b(?:false|true)\b/,
+	'function': /\b[A-Za-z][A-Za-z0-9]*(?=\()/,
 	'number': /\b\d+\b/,
 	'operator': /=|\.\./,
 	'punctuation': /[{}[\];(),:]/
