@@ -38,6 +38,9 @@
 		"aql": "AQL",
 		"ino": "Arduino",
 		"arff": "ARFF",
+		"armasm": "ARM Assembly",
+		"arm-asm": "ARM Assembly",
+		"art": "Arturo",
 		"asciidoc": "AsciiDoc",
 		"adoc": "AsciiDoc",
 		"aspnet": "ASP.NET (C#)",
@@ -49,10 +52,15 @@
 		"avs": "AviSynth",
 		"avro-idl": "Avro IDL",
 		"avdl": "Avro IDL",
+		"awk": "AWK",
+		"gawk": "GAWK",
+		"sh": "Shell",
 		"basic": "BASIC",
 		"bbcode": "BBcode",
+		"bbj": "BBj",
 		"bnf": "BNF",
 		"rbnf": "RBNF",
+		"bqn": "BQN",
 		"bsl": "BSL (1C:Enterprise)",
 		"oscript": "OneScript",
 		"csharp": "C#",
@@ -62,6 +70,11 @@
 		"cfscript": "CFScript",
 		"cfc": "CFScript",
 		"cil": "CIL",
+		"cilkc": "Cilk/C",
+		"cilk-c": "Cilk/C",
+		"cilkcpp": "Cilk/C++",
+		"cilk-cpp": "Cilk/C++",
+		"cilk": "Cilk/C++",
 		"cmake": "CMake",
 		"cobol": "COBOL",
 		"coffee": "CoffeeScript",
@@ -69,6 +82,7 @@
 		"csp": "Content-Security-Policy",
 		"css-extras": "CSS Extras",
 		"csv": "CSV",
+		"cue": "CUE",
 		"dataweave": "DataWeave",
 		"dax": "DAX",
 		"django": "Django/Jinja2",
@@ -95,9 +109,13 @@
 		"gcode": "G-code",
 		"gdscript": "GDScript",
 		"gedcom": "GEDCOM",
+		"gettext": "gettext",
+		"po": "gettext",
 		"glsl": "GLSL",
 		"gn": "GN",
 		"gni": "GN",
+		"linker-script": "GNU Linker Script",
+		"ld": "GNU Linker Script",
 		"go-module": "Go module",
 		"go-mod": "Go module",
 		"graphql": "GraphQL",
@@ -150,6 +168,7 @@
 		"matlab": "MATLAB",
 		"maxscript": "MAXScript",
 		"mel": "MEL",
+		"metafont": "METAFONT",
 		"mongodb": "MongoDB",
 		"moon": "MoonScript",
 		"n1ql": "N1QL",
@@ -178,6 +197,8 @@
 		"php": "PHP",
 		"phpdoc": "PHPDoc",
 		"php-extras": "PHP Extras",
+		"plant-uml": "PlantUML",
+		"plantuml": "PlantUML",
 		"plsql": "PL/SQL",
 		"powerquery": "PowerQuery",
 		"pq": "PowerQuery",
@@ -201,13 +222,14 @@
 		"tsx": "React TSX",
 		"renpy": "Ren'py",
 		"rpy": "Ren'py",
+		"res": "ReScript",
 		"rest": "reST (reStructuredText)",
 		"robotframework": "Robot Framework",
 		"robot": "Robot Framework",
 		"rb": "Ruby",
 		"sas": "SAS",
 		"sass": "Sass (Sass)",
-		"scss": "Sass (Scss)",
+		"scss": "Sass (SCSS)",
 		"shell-session": "Shell session",
 		"sh-session": "Shell session",
 		"shellsession": "Shell session",
@@ -223,7 +245,10 @@
 		"splunk-spl": "Splunk SPL",
 		"sqf": "SQF: Status Quo Function (Arma 3)",
 		"sql": "SQL",
+		"stata": "Stata Ado",
 		"iecst": "Structured Text (IEC 61131-3)",
+		"supercollider": "SuperCollider",
+		"sclang": "SuperCollider",
 		"systemd": "Systemd configuration file",
 		"t4-templating": "T4 templating",
 		"t4-cs": "T4 Text Templates (C#)",
@@ -251,6 +276,7 @@
 		"wasm": "WebAssembly",
 		"web-idl": "Web IDL",
 		"webidl": "Web IDL",
+		"wgsl": "WGSL",
 		"wiki": "Wiki markup",
 		"wolfram": "Wolfram language",
 		"nb": "Mathematica Notebook",
